

from __future__ import print_function, unicode_literals, absolute_import, division
from reahl.doc.examples.tutorial.ajax.ajax import WidgetRefreshUI

web.site_root = WidgetRefreshUI 
